package
Version:
v0.0.0-...-0bce360
Opens a new window with list of versions in this module.
Published: Mar 7, 2024
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Validate(s interface{}) error
type Error struct {
Field string `json:"field"`
Tag string `json:"tag"`
Value string `json:"value"`
Error string `json:"error"`
}
type Errors struct {
Message string `json:"message"`
Errors map[string][]Error `json:"errors"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.